@@ -1,20 +1,26 @@
-"""A Python specification is an abstract requirement definition of an interpreter"""
+"""A Python specification is an abstract requirement definition of an interpreter."""
 
 from __future__ import annotations
 
 import os
 import re
-from collections import OrderedDict
-
-from virtualenv.info import fs_is_case_sensitive
 
 PATTERN = re.compile(r"^(?P<impl>[a-zA-Z]+)?(?P<version>[0-9.]+)?(?:-(?P<arch>32|64))?$")
 
 
 class PythonSpec:
-    """Contains specification about a Python Interpreter"""
+    """Contains specification about a Python Interpreter."""
 
-    def __init__(self, str_spec, implementation, major, minor, micro, architecture, path):
+    def __init__(  # noqa: PLR0913
+        self,
+        str_spec: str,
+        implementation: str | None,
+        major: int | None,
+        minor: int | None,
+        micro: int | None,
+        architecture: int | None,
+        path: str | None,
+    ) -> None:
         self.str_spec = str_spec
         self.implementation = implementation
         self.major = major
@@ -24,9 +30,9 @@ class PythonSpec:
         self.path = path
 
     @classmethod
-    def from_string_spec(cls, string_spec):
+    def from_string_spec(cls, string_spec: str):  # noqa: C901, PLR0912
         impl, major, minor, micro, arch, path = None, None, None, None, None, None
-        if os.path.isabs(string_spec):
+        if os.path.isabs(string_spec):  # noqa: PLR1702
             path = string_spec
         else:
             ok = False
@@ -41,23 +47,23 @@ class PythonSpec:
                     version = groups["version"]
                     if version is not None:
                         versions = tuple(int(i) for i in version.split(".") if i)
-                        if len(versions) > 3:
-                            raise ValueError
-                        if len(versions) == 3:
+                        if len(versions) > 3:  # noqa: PLR2004
+                            raise ValueError  # noqa: TRY301
+                        if len(versions) == 3:  # noqa: PLR2004
                             major, minor, micro = versions
-                        elif len(versions) == 2:
+                        elif len(versions) == 2:  # noqa: PLR2004
                             major, minor = versions
                         elif len(versions) == 1:
                             version_data = versions[0]
                             major = int(str(version_data)[0])  # first digit major
-                            if version_data > 9:
+                            if version_data > 9:  # noqa: PLR2004
                                 minor = int(str(version_data)[1:])
                     ok = True
                 except ValueError:
                     pass
                 else:
                     impl = groups["impl"]
-                    if impl == "py" or impl == "python":
+                    if impl in {"py", "python"}:
                         impl = None
                     arch = _int_or_none(groups["arch"])
 
@@ -66,34 +72,25 @@ class PythonSpec:
 
         return cls(string_spec, impl, major, minor, micro, arch, path)
 
-    def generate_names(self):
-        impls = OrderedDict()
-        if self.implementation:
-            # first consider implementation as it is
-            impls[self.implementation] = False
-            if fs_is_case_sensitive():
-                # for case sensitive file systems consider lower and upper case versions too
-                # trivia: MacBooks and all pre 2018 Windows-es were case insensitive by default
-                impls[self.implementation.lower()] = False
-                impls[self.implementation.upper()] = False
-        impls["python"] = True  # finally consider python as alias, implementation must match now
-        version = self.major, self.minor, self.micro
-        try:
-            version = version[: version.index(None)]
-        except ValueError:
-            pass
-        for impl, match in impls.items():
-            for at in range(len(version), -1, -1):
-                cur_ver = version[0:at]
-                spec = f"{impl}{'.'.join(str(i) for i in cur_ver)}"
-                yield spec, match
+    def generate_re(self, *, windows: bool) -> re.Pattern:
+        """Generate a regular expression for matching against a filename."""
+        version = r"{}(\.{}(\.{})?)?".format(
+            *(r"\d+" if v is None else v for v in (self.major, self.minor, self.micro))
+        )
+        impl = "python" if self.implementation is None else f"python|{re.escape(self.implementation)}"
+        suffix = r"\.exe" if windows else ""
+        # Try matching `direct` first, so the `direct` group is filled when possible.
+        return re.compile(
+            rf"(?P<impl>{impl})(?P<v>{version}){suffix}$",
+            flags=re.IGNORECASE,
+        )
 
     @property
     def is_abs(self):
         return self.path is not None and os.path.isabs(self.path)
 
     def satisfies(self, spec):
-        """called when there's a candidate metadata spec to see if compatible - e.g. PEP-514 on Windows"""
+        """Called when there's a candidate metadata spec to see if compatible - e.g. PEP-514 on Windows."""
         if spec.is_abs and self.is_abs and self.path != spec.path:
             return False
         if spec.implementation is not None and spec.implementation.lower() != self.implementation.lower():
@@ -106,7 +103,7 @@ class PythonSpec:
                 return False
         return True
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         name = type(self).__name__
         params = "implementation", "major", "minor", "micro", "architecture", "path"
         return f"{name}({', '.join(f'{k}={getattr(self, k)}' for k in params if getattr(self, k) is not None)})"
