@@ -16,16 +16,25 @@ from virtualenv.info import fs_supports_symlink
 
 @pytest.mark.skipif(not fs_supports_symlink(), reason="symlink not supported")
 @pytest.mark.parametrize("case", ["mixed", "lower", "upper"])
-def test_discovery_via_path(monkeypatch, case, tmp_path, caplog, session_app_data):
+@pytest.mark.parametrize("specificity", ["more", "less"])
+def test_discovery_via_path(monkeypatch, case, specificity, tmp_path, caplog, session_app_data):  # noqa: PLR0913
     caplog.set_level(logging.DEBUG)
     current = PythonInfo.current_system(session_app_data)
-    core = f"somethingVeryCryptic{'.'.join(str(i) for i in current.version_info[0:3])}"
     name = "somethingVeryCryptic"
     if case == "lower":
         name = name.lower()
     elif case == "upper":
         name = name.upper()
-    exe_name = f"{name}{current.version_info.major}{'.exe' if sys.platform == 'win32' else ''}"
+    if specificity == "more":
+        # e.g. spec: python3, exe: /bin/python3.12
+        core_ver = current.version_info.major
+        exe_ver = ".".join(str(i) for i in current.version_info[0:2])
+    elif specificity == "less":
+        # e.g. spec: python3.12.1, exe: /bin/python3
+        core_ver = ".".join(str(i) for i in current.version_info[0:3])
+        exe_ver = current.version_info.major
+    core = f"somethingVeryCryptic{core_ver}"
+    exe_name = f"{name}{exe_ver}{'.exe' if sys.platform == 'win32' else ''}"
     target = tmp_path / current.install_path("scripts")
     target.mkdir(parents=True)
     executable = target / exe_name
@@ -33,7 +42,7 @@ def test_discovery_via_path(monkeypatch, case, tmp_path, caplog, session_app_dat
     pyvenv_cfg = Path(sys.executable).parents[1] / "pyvenv.cfg"
     if pyvenv_cfg.exists():
         (target / pyvenv_cfg.name).write_bytes(pyvenv_cfg.read_bytes())
-    new_path = os.pathsep.join([str(target)] + os.environ.get("PATH", "").split(os.pathsep))
+    new_path = os.pathsep.join([str(target), *os.environ.get("PATH", "").split(os.pathsep)])
     monkeypatch.setenv("PATH", new_path)
     interpreter = get_interpreter(core, [])
 
